@@ -16,25 +16,30 @@ my $DEFAULT_TIMEOUT = 30;
 
 has(
 
-	Config => {},
-	Volumes => {},
-	Image => {},
     Id => undef, # new ID attribute from api#v1.12
-	NetworkSettings => {},
-	VolumesRW => {},
-	HostsPath => '',
-	State => '',
-	HostnamePath => '',
-	Args => [],
-	HostConfig => {},
-	ResolvConfPath => '',
-	Path => '',
 	Created => '',
-	Driver => '',
+	Path => '',
+	Args => [],
+	State => {},
+	Image => '',
+	NetworkSettings => {},
+    HostnamePath => '',
+	ResolvConfPath => '',
+	HostsPath => '',
+	LogPath => '',
 	Name => '',
-    ProcessLabel => '',
+    RestartCount => undef,
+	Driver => '',
+   	ExecDriver => '',
+	ProcessLabel => '',
     MountLabel => '',
-    ExecDriver => '',
+    AppArmorProfile =>  "",
+    ExecIDs => undef,
+    
+    HostConfig => {},
+    GraphDriver => {},
+    Mounts => [],
+	Config => {},
     
 );
 
@@ -65,15 +70,19 @@ sub get{
 		args=>\%args,
 		
 		__callback => sub {
-
+    
 			$self->populate($_[0]);
 
+
 			# load config obj replacing config hash
 			if(my %h = %{$self->Config}){ 
-
 				$self->Config(Eixo::Docker::Config->new(%h))
 			}
 
+			if(my %h = %{$self->HostConfig}){
+				$self->HostConfig(Eixo::Docker::HostConfig->new(%h))
+			}
+
 			$self;
 		},
 	);
@@ -100,16 +109,15 @@ sub getByName {
 
 sub getAll {
 
-	my ($self,%args) = @_;
+    my ($self,%args) = @_;
 
-	my $list  = [];
+    my $list  = [];
 
-	my $args = {
+    my $args = {
         all => 1,
         limit => $args{limit} || 1000,
     };
 
-    
     $self->api->getContainers(
 
         args => $args,
@@ -141,24 +149,37 @@ sub create {
 
 	# validate attrs and initialize default values not setted
 	my $config = Eixo::Docker::Config->new(%attrs);
-	
+    my $hostconfig = Eixo::Docker::HostConfig->new(%{$attrs{HostConfig}});
+    delete($config->{api});
+    delete($hostconfig->{api});
+
+    my $create_data = {
+
+        %$config, 
+        HostConfig => {%$hostconfig},
+        
+    };
+
 	$args->{action} = 'create';
-	$args->{POST_DATA}  = $config;
+	$args->{POST_DATA}  = $create_data;
+
 
 	my $res = $self->api->postContainers(
-			args => $args,
 
-			get_params => [qw(name)],
+	    args => $args,
 
-            __callback => sub {
-                my $result = $_[0];
+	    get_params => [qw(name)],
 
-                #return container fully loaded
-                $self->get(id => $result->{Id});
+        __callback => sub {
+            my $result = $_[0];
 
-                $self;
-            }
-	);
+            #return container fully loaded
+            $self->get(id => $result->{Id});
+
+            $self;
+
+        }
+    );
 
 }
 
@@ -203,7 +224,6 @@ sub start {
 
     $self->__exec("start", %args);
 
-
 }
 
 sub stop {
@@ -329,6 +349,38 @@ sub top{
 
 }
 
+sub rename{
+	my ($self, %args) = @_;
+
+	$args{id} = $self->Id unless($args{id});
+
+	$args{__implicit_format} = 1;
+
+	$args{action} = 'rename';
+
+	$self->api->postContainers(
+
+		args=>\%args,
+
+		get_params=>[qw(name)],
+
+		needed=>[qw(name)],
+
+		__callback=>sub{
+            
+            my $result = $_[0];
+
+            #return container fully loaded
+            $self->get(id => $result->{Id});
+
+            $self;
+		}
+
+	);
+}
+
+
+
 sub __exec {
     my ($self, $action, %args) = @_;
 
